McpEvent

Enum McpEvent 

pub enum McpEvent {
Show 14 variants ServerStarted { addr: String, }, ToolListRequested { client_addr: String, }, ToolListReturned { client_addr: String, tool_count: usize, }, ToolCallReceived { client_addr: String, tool_name: String, parameters: Value, }, ToolCallCompleted { client_addr: String, tool_name: String, success: bool, error: Option<String>, duration_ms: u64, }, ToolError { source: String, tool_name: String, error: String, duration_ms: u64, }, RequestRejected { client_addr: String, reason: String, }, ConnectionInitialized { endpoint: String, tool_count: usize, }, ConnectionClosed { endpoint: String, }, ToolsDiscovered { endpoint: String, tool_count: usize, tool_names: Vec<String>, }, CacheHit { endpoint: String, tool_count: usize, }, CacheExpired { endpoint: String, }, RemoteToolCallStarted { endpoint: String, tool_name: String, parameters: Value, }, RemoteToolCallCompleted { endpoint: String, tool_name: String, success: bool, error: Option<String>, duration_ms: u64, },
}
Events emitted by MCP servers and MCP clients. Events emitted by MCP servers and MCP HTTP clients.

Variants



ServerStarted

The HTTP server started listening on the supplied address.

Fields

addr: String

Bound socket address.



ToolListRequested

A tool-list request was received from a client.

Fields

client_addr: String

Client IP address.



ToolListReturned

A tool-list response was returned to the client.

Fields

client_addr: String

Client IP address.

tool_count: usize

Number of tools returned.



ToolCallReceived

A tool execution request was received from a client.

Fields

client_addr: String

Client IP address.

tool_name: String

Requested tool name.

parameters: Value

Raw JSON parameters.



ToolCallCompleted

A server-side tool execution completed.

Fields

client_addr: String

Client IP address.

tool_name: String

Tool name.

success: bool

Whether execution succeeded.

error: Option<String>

Optional error message.

duration_ms: u64

Execution duration in milliseconds.



ToolError

A tool call failed at the transport or protocol layer.

Fields

source: String

Client IP or remote endpoint URL.

tool_name: String

Tool name.

error: String

Error message.

duration_ms: u64

Elapsed time in milliseconds.



RequestRejected

A request was rejected before tool execution.

Fields

client_addr: String

Client IP address.

reason: String

Human-readable rejection reason.



ConnectionInitialized

An MCP client initialized successfully.

Fields

endpoint: String

Remote endpoint URL.

tool_count: usize

Number of discovered tools.



ConnectionClosed

An MCP client connection was closed.

Fields

endpoint: String

Remote endpoint URL.



ToolsDiscovered

The tool cache was refreshed from the remote endpoint.

Fields

endpoint: String

Remote endpoint URL.

tool_count: usize

Number of discovered tools.

tool_names: Vec<String>

Discovered tool names.



CacheHit

Cached tool metadata was used.

Fields

endpoint: String

Remote endpoint URL.

tool_count: usize

Number of cached tools.



CacheExpired

Cached tool metadata expired.

Fields

endpoint: String

Remote endpoint URL.



RemoteToolCallStarted

A remote tool call is being dispatched.

Fields

endpoint: String

Remote endpoint URL.

tool_name: String

Tool name.

parameters: Value

JSON parameters.



RemoteToolCallCompleted

A remote tool call completed.

Fields

endpoint: String

Remote endpoint URL.

tool_name: String

Tool name.

success: bool

Whether the tool result succeeded.

error: Option<String>

Optional error message.

duration_ms: u64

Round-trip duration in milliseconds.