pub enum ThoughtRelationKind {
References,
Summarizes,
Corrects,
Invalidates,
CausedBy,
Supports,
Contradicts,
DerivedFrom,
ContinuesFrom,
RelatedTo,
}Expand description
Why a thought points to another thought.
Example
use mentisdb::ThoughtRelationKind;
assert_eq!(ThoughtRelationKind::Corrects as u8, ThoughtRelationKind::Corrects as u8);Variants
References
A general back-reference.
Summarizes
The source thought summarizes the target thought.
Corrects
The source thought corrects the target thought.
Invalidates
The source thought invalidates the target thought.
CausedBy
The source thought was caused by the target thought.
Supports
The source thought supports the target thought.
Contradicts
The source thought contradicts the target thought.
DerivedFrom
The source thought was derived from the target thought.
ContinuesFrom
The source thought continues the work or state of the target thought.
RelatedTo
A generic semantic relation exists between source and target.